--------------------------------------------------------------------------------
-- CERN BE-CO-HT
--
-- https://www.ohwr.org/projects/wr2rf-vme
--------------------------------------------------------------------------------
--
-- unit name:   wr2rf_reset_logic
--
-- description: Provides wrapper for how the DDS sync, RFNCO and rf_t1_sync signals
-- are produced
--
--------------------------------------------------------------------------------
-- Copyright CERN 2020
--------------------------------------------------------------------------------
-- Copyright and related rights are licensed under the Solderpad Hardware
-- License, Version 2.0 (the "License"); you may not use this file except
-- in compliance with the License. You may obtain a copy of the License at
-- http://solderpad.org/licenses/SHL-2.0.
-- Unless required by applicable law or agreed to in writing, software,
-- hardware and materials distributed under this License is distributed on an
-- "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
-- or implied. See the License for the specific language governing permissions
-- and limitations under the License.
--------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

library unisim;
use unisim.vcomponents.all;

use work.wishbone_pkg.all;

entity wr2rf_dds is

   port (
      clk250m_i        : in  std_logic;

      dds_sync_p_o     : out std_logic;
      dds_sync_n_o     : out std_logic );

   attribute keep_hierarchy              : STRING;
   attribute keep_hierarchy of wr2rf_dds : entity is "yes";
   
end entity;

architecture rtl of wr2rf_dds is

   -- We need to register pack the iob for dds_sync
   -- dds sync is a common master clock passed to each of the
   -- ad9910 throughout the installations. It ensures common
   -- timing on our DDSs. It is _not_ used to synchronise the
   -- ad9910 outputs - see ioupdate for that
   signal dds_sync   : std_logic;
   
begin

   -- We need the DDS SYNC_CLK to be one quarter of the DDS SYSCLK frequency (1 GHz)
   oddr_inst : oddr
      generic map (
         ddr_clk_edge   => "same_edge",
         init           => '0',
         srtype         => "async" )
      port map (
         d1             => '1',
         d2             => '0',
         c              => clk250m_i,
         ce             => '1',
         q              => dds_sync,
         r              => '0',
         s              => '0' );
   
   dds_sync_i : obufds
      generic map(
         slew => "FAST" )
      port map(
         o    => dds_sync_p_o,
         ob   => dds_sync_n_o,
         i    => dds_sync );

end architecture;
